==> xlniuxdata-vipgame-1.0.33-20151112.053636-31-sources.jar: com/xunlei/niux/data/vipgame/vo/CustomerInfo.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Table;

/**
 * 客户信息
 * @author lisu
 *  2013-02-22
 */
@Table(tableName = "customerinfo", pkFieldName = "seqId", pkFieldAssign = false)
public class CustomerInfo {

	private Long seqId;
	private String uid;
	private String account;
	private String username;
	private String sex;
	private Integer age;
	private String birthday;
	private String degree;
	private String profession;
	private String area;
	private String qq;
	private String email;
	private String phone;
	private String oldphone;
	private String inputby;
	private String inputtime;
	private String editby;
	private String edittime;
	private Boolean checkFlag;
	private Boolean checkPhone;
	private String address;
	private String annualSalary;
	private String family;
	private String lostLogin;
	private String lostPay;
    private String firstTreat;
    private String firstTreatResult;
    private String secondTreat;
    private String secondTreatResult;
    private String firstTreatLogin;
    private String firstTreatResultLogin;
    private String secondTreatLogin;
    private String secondTreatResultLogin;

    public String getFirstTreatLogin() {
        return firstTreatLogin;
    }

    public void setFirstTreatLogin(String firstTreatLogin) {
        this.firstTreatLogin = firstTreatLogin;
    }

    public String getFirstTreatResultLogin() {
        return firstTreatResultLogin;
    }

    public void setFirstTreatResultLogin(String firstTreatResultLogin) {
        this.firstTreatResultLogin = firstTreatResultLogin;
    }

    public String getSecondTreatLogin() {
        return secondTreatLogin;
    }

    public void setSecondTreatLogin(String secondTreatLogin) {
        this.secondTreatLogin = secondTreatLogin;
    }

    public String getSecondTreatResultLogin() {
        return secondTreatResultLogin;
    }

    public void setSecondTreatResultLogin(String secondTreatResultLogin) {
        this.secondTreatResultLogin = secondTreatResultLogin;
    }

    public String getFirstTreat() {
        return firstTreat;
    }

    public void setFirstTreat(String firstTreat) {
        this.firstTreat = firstTreat;
    }

    public String getFirstTreatResult() {
        return firstTreatResult;
    }

    public void setFirstTreatResult(String firstTreatResult) {
        this.firstTreatResult = firstTreatResult;
    }

    public String getSecondTreat() {
        return secondTreat;
    }

    public void setSecondTreat(String secondTreat) {
        this.secondTreat = secondTreat;
    }

    public String getSecondTreatResult() {
        return secondTreatResult;
    }

    public void setSecondTreatResult(String secondTreatResult) {
        this.secondTreatResult = secondTreatResult;
    }

    public String getAnnualSalary() {
        return annualSalary;
    }

    public void setAnnualSalary(String annualSalary) {
        this.annualSalary = annualSalary;
    }

    public String getFamily() {
        return family;
    }

    public void setFamily(String family) {
        this.family = family;
    }

    public String getLostLogin() {
        return lostLogin;
    }

    public void setLostLogin(String lostLogin) {
        this.lostLogin = lostLogin;
    }

    public String getLostPay() {
        return lostPay;
    }

    public void setLostPay(String lostPay) {
        this.lostPay = lostPay;
    }

    public String getOldphone() {
		return oldphone;
	}
	public void setOldphone(String oldphone) {
		this.oldphone = oldphone;
	}
	public String getAddress() {
		return address;
	}
	public void setAddress(String address) {
		this.address = address;
	}
	public Boolean getCheckPhone() {
		return checkPhone;
	}
	public void setCheckPhone(Boolean checkPhone) {
		this.checkPhone = checkPhone;
	}
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public String getUid() {
		return uid;
	}
	public void setUid(String uid) {
		this.uid = uid;
	}
	public String getUsername() {
		return username;
	}
	public void setUsername(String username) {
		this.username = username;
	}
	public String getSex() {
		return sex;
	}
	public void setSex(String sex) {
		this.sex = sex;
	}
	public Integer getAge() {
		return age;
	}
	public void setAge(Integer age) {
		this.age = age;
	}
	public String getBirthday() {
		return birthday;
	}
	public void setBirthday(String birthday) {
		this.birthday = birthday;
	}
	public String getDegree() {
		return degree;
	}
	public void setDegree(String degree) {
		this.degree = degree;
	}
	public String getProfession() {
		return profession;
	}
	public void setProfession(String profession) {
		this.profession = profession;
	}
	public String getArea() {
		return area;
	}
	public void setArea(String area) {
		this.area = area;
	}
	public String getQq() {
		return qq;
	}
	public void setQq(String qq) {
		this.qq = qq;
	}
	public String getEmail() {
		return email;
	}
	public void setEmail(String email) {
		this.email = email;
	}
	public String getPhone() {
		return phone;
	}
	public void setPhone(String phone) {
		this.phone = phone;
	}
	public String getInputby() {
		return inputby;
	}
	public void setInputby(String inputby) {
		this.inputby = inputby;
	}
	public String getInputtime() {
		return inputtime;
	}
	public void setInputtime(String inputtime) {
		this.inputtime = inputtime;
	}
	public String getEditby() {
		return editby;
	}
	public void setEditby(String editby) {
		this.editby = editby;
	}
	public String getEdittime() {
		return edittime;
	}
	public void setEdittime(String edittime) {
		this.edittime = edittime;
	}
	public Boolean getCheckFlag() {
		return checkFlag;
	}
	public void setCheckFlag(Boolean checkFlag) {
		this.checkFlag = checkFlag;
	}
	public String getAccount() {
		return account;
	}
	public void setAccount(String account) {
		this.account = account;
	}
	
}

==> xlniuxdata-vipgame-1.0.58-20160429.084505-3-sources.jar: com/xunlei/niux/data/vipgame/vo/CustomerInfo.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Table;

/**
 * 客户信息
 * @author lisu
 *  2013-02-22
 */
@Table(tableName = "customerinfo", pkFieldName = "seqId", pkFieldAssign = false)
public class CustomerInfo {

	private Long seqId;
	private String uid;
	private String account;
	private String username;
	private String sex;
	private Integer age;
	private String birthday;
	private String degree;
	private String profession;
	private String area;
	private String qq;
	private String email;
	private String phone;
	private String oldphone;
	private String inputby;
	private String inputtime;
	private String editby;
	private String edittime;
	private Boolean checkFlag;
	private Boolean checkPhone;
	private String address;
	private String annualSalary;
	private String family;
	private String lostLogin;
	private String lostPay;
    private String firstTreat;
    private String firstTreatResult;
    private String secondTreat;
    private String secondTreatResult;
    private String firstTreatLogin;
    private String firstTreatResultLogin;
    private String secondTreatLogin;
    private String secondTreatResultLogin;

	//新增
	private String nativePlaceProvice;
	private String nativePlaceCity;
	private String familyGroup;
	private Integer married;
	private String gameType;
	private String interest;
	private Integer gameFrequency;
	private Integer netAge;
	private Integer gameAge;
	private Integer pcBandwidth;
	private Integer pcAddr;
	private Integer mobileBandwidth;
	private Integer mobileAddr;


	public String getFirstTreatLogin() {
        return firstTreatLogin;
    }

    public void setFirstTreatLogin(String firstTreatLogin) {
        this.firstTreatLogin = firstTreatLogin;
    }

    public String getFirstTreatResultLogin() {
        return firstTreatResultLogin;
    }

    public void setFirstTreatResultLogin(String firstTreatResultLogin) {
        this.firstTreatResultLogin = firstTreatResultLogin;
    }

    public String getSecondTreatLogin() {
        return secondTreatLogin;
    }

    public void setSecondTreatLogin(String secondTreatLogin) {
        this.secondTreatLogin = secondTreatLogin;
    }

    public String getSecondTreatResultLogin() {
        return secondTreatResultLogin;
    }

    public void setSecondTreatResultLogin(String secondTreatResultLogin) {
        this.secondTreatResultLogin = secondTreatResultLogin;
    }

    public String getFirstTreat() {
        return firstTreat;
    }

    public void setFirstTreat(String firstTreat) {
        this.firstTreat = firstTreat;
    }

    public String getFirstTreatResult() {
        return firstTreatResult;
    }

    public void setFirstTreatResult(String firstTreatResult) {
        this.firstTreatResult = firstTreatResult;
    }

    public String getSecondTreat() {
        return secondTreat;
    }

    public void setSecondTreat(String secondTreat) {
        this.secondTreat = secondTreat;
    }

    public String getSecondTreatResult() {
        return secondTreatResult;
    }

    public void setSecondTreatResult(String secondTreatResult) {
        this.secondTreatResult = secondTreatResult;
    }

    public String getAnnualSalary() {
        return annualSalary;
    }

    public void setAnnualSalary(String annualSalary) {
        this.annualSalary = annualSalary;
    }

    public String getFamily() {
        return family;
    }

    public void setFamily(String family) {
        this.family = family;
    }

    public String getLostLogin() {
        return lostLogin;
    }

    public void setLostLogin(String lostLogin) {
        this.lostLogin = lostLogin;
    }

    public String getLostPay() {
        return lostPay;
    }

    public void setLostPay(String lostPay) {
        this.lostPay = lostPay;
    }

    public String getOldphone() {
		return oldphone;
	}
	public void setOldphone(String oldphone) {
		this.oldphone = oldphone;
	}
	public String getAddress() {
		return address;
	}
	public void setAddress(String address) {
		this.address = address;
	}
	public Boolean getCheckPhone() {
		return checkPhone;
	}
	public void setCheckPhone(Boolean checkPhone) {
		this.checkPhone = checkPhone;
	}
	public Long getSeqId() {
		return seqId;
	}
	public void setSeqId(Long seqId) {
		this.seqId = seqId;
	}
	public String getUid() {
		return uid;
	}
	public void setUid(String uid) {
		this.uid = uid;
	}
	public String getUsername() {
		return username;
	}
	public void setUsername(String username) {
		this.username = username;
	}
	public String getSex() {
		return sex;
	}
	public void setSex(String sex) {
		this.sex = sex;
	}
	public Integer getAge() {
		return age;
	}
	public void setAge(Integer age) {
		this.age = age;
	}
	public String getBirthday() {
		return birthday;
	}
	public void setBirthday(String birthday) {
		this.birthday = birthday;
	}
	public String getDegree() {
		return degree;
	}
	public void setDegree(String degree) {
		this.degree = degree;
	}
	public String getProfession() {
		return profession;
	}
	public void setProfession(String profession) {
		this.profession = profession;
	}
	public String getArea() {
		return area;
	}
	public void setArea(String area) {
		this.area = area;
	}
	public String getQq() {
		return qq;
	}
	public void setQq(String qq) {
		this.qq = qq;
	}
	public String getEmail() {
		return email;
	}
	public void setEmail(String email) {
		this.email = email;
	}
	public String getPhone() {
		return phone;
	}
	public void setPhone(String phone) {
		this.phone = phone;
	}
	public String getInputby() {
		return inputby;
	}
	public void setInputby(String inputby) {
		this.inputby = inputby;
	}
	public String getInputtime() {
		return inputtime;
	}
	public void setInputtime(String inputtime) {
		this.inputtime = inputtime;
	}
	public String getEditby() {
		return editby;
	}
	public void setEditby(String editby) {
		this.editby = editby;
	}
	public String getEdittime() {
		return edittime;
	}
	public void setEdittime(String edittime) {
		this.edittime = edittime;
	}
	public Boolean getCheckFlag() {
		return checkFlag;
	}
	public void setCheckFlag(Boolean checkFlag) {
		this.checkFlag = checkFlag;
	}
	public String getAccount() {
		return account;
	}
	public void setAccount(String account) {
		this.account = account;
	}

	public String getNativePlaceProvice() {
		return nativePlaceProvice;
	}

	public void setNativePlaceProvice(String nativePlaceProvice) {
		this.nativePlaceProvice = nativePlaceProvice;
	}

	public String getNativePlaceCity() {
		return nativePlaceCity;
	}

	public void setNativePlaceCity(String nativePlaceCity) {
		this.nativePlaceCity = nativePlaceCity;
	}

	public String getFamilyGroup() {
		return familyGroup;
	}

	public void setFamilyGroup(String familyGroup) {
		this.familyGroup = familyGroup;
	}

	public Integer getMarried() {
		return married;
	}

	public void setMarried(Integer married) {
		this.married = married;
	}

	public String getGameType() {
		return gameType;
	}

	public void setGameType(String gameType) {
		this.gameType = gameType;
	}

	public String getInterest() {
		return interest;
	}

	public void setInterest(String interest) {
		this.interest = interest;
	}

	public Integer getGameFrequency() {
		return gameFrequency;
	}

	public void setGameFrequency(Integer gameFrequency) {
		this.gameFrequency = gameFrequency;
	}

	public Integer getNetAge() {
		return netAge;
	}

	public void setNetAge(Integer netAge) {
		this.netAge = netAge;
	}

	public Integer getGameAge() {
		return gameAge;
	}

	public void setGameAge(Integer gameAge) {
		this.gameAge = gameAge;
	}

	public Integer getPcBandwidth() {
		return pcBandwidth;
	}

	public void setPcBandwidth(Integer pcBandwidth) {
		this.pcBandwidth = pcBandwidth;
	}

	public Integer getPcAddr() {
		return pcAddr;
	}

	public void setPcAddr(Integer pcAddr) {
		this.pcAddr = pcAddr;
	}

	public Integer getMobileBandwidth() {
		return mobileBandwidth;
	}

	public void setMobileBandwidth(Integer mobileBandwidth) {
		this.mobileBandwidth = mobileBandwidth;
	}

	public Integer getMobileAddr() {
		return mobileAddr;
	}

	public void setMobileAddr(Integer mobileAddr) {
		this.mobileAddr = mobileAddr;
	}
}
